import { encoding, serializeLayout, toChainId, } from "@wormhole-foundation/sdk-base";
import { keccak256, } from "@wormhole-foundation/sdk-definitions";
import { nativeTokenTransferLayout, nttManagerMessageLayout, transceiverInstructionLayout, } from "./layouts/index.js";
/**
 * @namespace Ntt
 */
export var Ntt;
(function (Ntt) {
    const _protocol = "Ntt";
    // TODO: should layoutify this but couldnt immediately figure out how to
    // specify the length of the array as an encoded value
    function encodeTransceiverInstructions(ixs) {
        if (ixs.length > 255)
            throw new Error(`Too many instructions (${ixs.length})`);
        return encoding.bytes.concat(new Uint8Array([ixs.length]), ...ixs.map((ix) => serializeLayout(transceiverInstructionLayout(), ix)));
    }
    Ntt.encodeTransceiverInstructions = encodeTransceiverInstructions;
    /**
     * messageDigest hashes a message for the Ntt manager, the digest is used
     * to uniquely identify the message
     * @param chain The chain that sent the message
     * @param message The ntt message to hash
     * @returns a 32 byte digest of the message
     */
    function messageDigest(chain, message) {
        return keccak256(encoding.bytes.concat(encoding.bignum.toBytes(toChainId(chain), 2), serializeLayout(nttManagerMessageLayout(nativeTokenTransferLayout), message)));
    }
    Ntt.messageDigest = messageDigest;
})(Ntt || (Ntt = {}));
export var WormholeNttTransceiver;
(function (WormholeNttTransceiver) {
    const _payloads = ["WormholeTransfer"];
})(WormholeNttTransceiver || (WormholeNttTransceiver = {}));
//# sourceMappingURL=ntt.js.map